==> nextcloud-app-tasks-0.9.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/pl.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Zadania",
    "Due yesterday" : "Na wczoraj",
    "Due today" : "Na dzisiaj",
    "Due tomorrow" : "Na jutro",
    "Due on" : "Na dzień",
    "Started yesterday" : "Rozpoczęło się wczoraj",
    "Starts today" : "Rozpoczyna się dziś",
    "Starts tomorrow" : "Rozpoczyna się jutro",
    "Started on" : "Rozpoczęło się",
    "Starts on" : "Rozpoczyna się",
    "[Remind me yesterday at ]HH:mm" : "[Przypomnij mi jutro o ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Przypomnij mi dziś o ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Przypomnij mi jutro o ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Przypomnij mi ]MMM DD, YYYY,[ o ]HH:mm",
    "Yesterday" : "Wczoraj",
    "Today" : "Dziś",
    "Tomorrow" : "Jutro",
    "in %s" : "w %s",
    "%s ago" : "%s temu",
    "seconds" : "sekund",
    "a minute" : "minutę",
    "%d minutes" : "%d minut",
    "an hour" : "godzinę",
    "%d hours" : "%d godzin",
    "a day" : "dzień",
    "%d days" : "%d dni",
    "a month" : "miesiąc",
    "%d months" : "%d miesięcy",
    "a year" : "rok",
    "%d years" : "%d lat",
    "week" : "tydzień",
    "weeks" : "tygodni",
    "day" : "dzień",
    "days" : "dniach",
    "hour" : "godzinę",
    "hours" : "godzin",
    "minute" : "minutę",
    "minutes" : "minut",
    "second" : "drugi",
    "before beginning" : "przed rozpoczęciem",
    "after beginning" : "po rozpoczęciu",
    "before end" : "przed końcem",
    "after end" : "po zakończeniu",
    "Comment" : "Komentarz",
    "Add a comment" : "Dodaj komentarz",
    "This will delete the Calendar \"%s\" and all of its entries." : "To usunie kalendarz \"%s\" i wszystkie jego wpisy.",
    "The name \"%s\" is already used." : "Nazwa \"%s\" jest już używana.",
    "An empty name is not allowed." : "Pusta nazwa nie jest dozwolona.",
    "Hidden" : "Ukryty",
    "Visible" : "Widoczny",
    "Automatic" : "Automatyczny",
    "Sunday" : "Niedziela",
    "Monday" : "Poniedziałek",
    "Tuesday" : "Wtorek",
    "Wednesday" : "Środa",
    "Thursday" : "Czwartek",
    "Friday" : "Piątek",
    "Saturday" : "Sobota",
    "Add an important item in \"%s\"..." : "Dodaj ważny element w \"%s\" ...",
    "Add an item due today in \"%s\"..." : "Dodaj element na dzisiaj w \"%s\" ...",
    "Add an item in \"%s\"..." : "Dodaj element w \"%s\" ...",
    "Add a current item in \"%s\"..." : "Dodaj aktualny element w \"%s\" ...",
    "Add a subtask to \"%s\"..." : "Dodaj podzadanie do \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n zakończone zadanie","%n zakończonych zadań","%n zakończonych zadań"],
    "Hours" : "Godzin",
    "Minutes" : "Minut",
    "Set due date" : "Ustaw datę wydarzenia",
    "%s %% completed" : "ukończono %s %%",
    "priority %s: " : "priorytet %s: ",
    "high" : "wysoki",
    "medium" : "średni",
    "low" : "niski",
    "no priority assigned" : "brak priorytetu",
    "Remind me" : "Przypomnij mi",
    "at the end" : "na końcu",
    "at the beginning" : "na początku",
    "Set start date" : "Ustaw datę rozpoczęcia",
    "{calendar} shared by {owner}" : "{calendar} współdzielony przez {owner}",
    "Unnamed" : "Bez nazwy",
    "Important" : "Ważne",
    "Week" : "Tydzień",
    "All" : "Wszystkie",
    "Current" : "Obecny",
    "Completed" : "Ukończono",
    "Delete" : "Usuń",
    "Cancel" : "Anuluj",
    "Edit" : "Edytuj",
    "Link" : "Link",
    "Download" : "Pobierz",
    "Save" : "Zapisz",
    "Add List..." : "Dodaj listę...",
    "New List" : "Nowa lista",
    "Settings" : "Ustawienia",
    "Start of week" : "Początek tygodnia",
    "Visibility of Smart Collections" : "Widoczność Smart Collections",
    "Change sort order" : "Zmień kierunek sortowania",
    "Default" : "Domyślny",
    "Due date" : "Data do",
    "Start date" : "Data od",
    "Priority" : "Priorytet",
    "Alphabetically" : "Alfabetycznie",
    "Manually" : "Ręcznie",
    "Load remaining completed tasks." : "Załaduj pozostałe ukończone zadania.",
    "All day" : "Cały dzień",
    "(New category)" : "(Nowa kategoria)",
    "Select categories..." : "Wybierz kategorie...",
    "Loading the task..." : "Ładowanie zadania...",
    "Task not found!" : "Nie znaleziono zadania!",
    "add a subtask to" : "dodaj podzadanie do"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/pl.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Zadania",
    "Due yesterday" : "Na wczoraj",
    "Due today" : "Na dzisiaj",
    "Due tomorrow" : "Na jutro",
    "Due on" : "Na dzień",
    "Started yesterday" : "Rozpoczęły się wczoraj",
    "Starts today" : "Rozpoczyna się dziś",
    "Starts tomorrow" : "Rozpoczynają się jutro",
    "Started on" : "Rozpoczęły się",
    "Starts on" : "Rozpoczynają się",
    "[Remind me yesterday at ]HH:mm" : "[Przypomnij mi jutro o ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Przypomnij mi dziś o ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Przypomnij mi jutro o ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Przypomnij mi ]MMM DD, YYYY,[ o ]HH:mm",
    "Yesterday" : "Wczoraj",
    "Today" : "Dziś",
    "Tomorrow" : "Jutro",
    "in %s" : "w %s",
    "%s ago" : "%s temu",
    "seconds" : "sekund",
    "a minute" : "minutę",
    "%d minutes" : "%d minut",
    "an hour" : "godzinę",
    "%d hours" : "%d godzin",
    "a day" : "dzień",
    "%d days" : "%d dni",
    "a month" : "miesiąc",
    "%d months" : "%d miesięcy",
    "a year" : "rok",
    "%d years" : "%d lat",
    "week" : "tydzień",
    "weeks" : "tygodni",
    "day" : "dzień",
    "days" : "dniach",
    "hour" : "godzinę",
    "hours" : "godzin",
    "minute" : "minutę",
    "minutes" : "minut",
    "second" : "drugi",
    "before beginning" : "przed rozpoczęciem",
    "after beginning" : "po rozpoczęciu",
    "before end" : "przed końcem",
    "after end" : "po zakończeniu",
    "Comment" : "Komentarz",
    "Add a comment" : "Dodaj komentarz",
    "This will delete the Calendar \"%s\" and all of its entries." : "To usunie kalendarz \"%s\" i wszystkie jego wpisy.",
    "The name \"%s\" is already used." : "Nazwa \"%s\" jest już używana.",
    "An empty name is not allowed." : "Pusta nazwa nie jest dozwolona.",
    "Hidden" : "Ukryty",
    "Visible" : "Widoczny",
    "Automatic" : "Automatyczny",
    "Sunday" : "Niedziela",
    "Monday" : "Poniedziałek",
    "Tuesday" : "Wtorek",
    "Wednesday" : "Środa",
    "Thursday" : "Czwartek",
    "Friday" : "Piątek",
    "Saturday" : "Sobota",
    "Add an important item in \"%s\"..." : "Dodaj ważny element w \"%s\" ...",
    "Add an item due today in \"%s\"..." : "Dodaj element na dzisiaj w \"%s\" ...",
    "Add an item in \"%s\"..." : "Dodaj element w \"%s\" ...",
    "Add a current item in \"%s\"..." : "Dodaj aktualny element w \"%s\" ...",
    "Add a subtask to \"%s\"..." : "Dodaj podzadanie do \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n zakończone zadanie","%n zakończonych zadań","%n zakończonych zadań","%n zakończonych zadań"],
    "Hours" : "Godzin",
    "Minutes" : "Minut",
    "Set due date" : "Ustaw datę wydarzenia",
    "%s %% completed" : "ukończono %s %%",
    "priority %s: " : "priorytet %s: ",
    "high" : "wysoki",
    "medium" : "średni",
    "low" : "niski",
    "no priority assigned" : "brak priorytetu",
    "Remind me" : "Przypomnij mi",
    "at the end" : "na końcu",
    "at the beginning" : "na początku",
    "Set start date" : "Ustaw datę rozpoczęcia",
    "{calendar} shared by {owner}" : "{calendar} współdzielony przez {owner}",
    "Unnamed" : "Bez nazwy",
    "Important" : "Ważne",
    "Week" : "Tydzień",
    "All" : "Wszystkie",
    "Current" : "Obecny",
    "Completed" : "Ukończono",
    "Delete" : "Usuń",
    "Cancel" : "Anuluj",
    "Edit" : "Edytuj",
    "Link" : "Link",
    "Download" : "Pobierz",
    "Save" : "Zapisz",
    "Add List..." : "Dodaj listę...",
    "New List" : "Nowa lista",
    "Settings" : "Ustawienia",
    "Start of week" : "Początek tygodnia",
    "Visibility of Smart Collections" : "Widoczność Smart Collections",
    "Change sort order" : "Zmień kierunek sortowania",
    "Default" : "Domyślny",
    "Due date" : "Data do",
    "Start date" : "Data od",
    "Priority" : "Priorytet",
    "Alphabetically" : "Alfabetycznie",
    "Manually" : "Ręcznie",
    "Load remaining completed tasks." : "Załaduj pozostałe ukończone zadania.",
    "All day" : "Cały dzień",
    "(New category)" : "(Nowa kategoria)",
    "Select categories..." : "Wybierz kategorie...",
    "Loading the task..." : "Ładowanie zadania...",
    "Task not found!" : "Nie znaleziono zadania!",
    "add a subtask to" : "dodaj podzadanie do"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
